@@ -1,8 +1,7 @@
 import logging
 import os
 import fnmatch
-import six
-from six.moves import queue
+import queue
 import time
 
 from wandb import util
@@ -14,7 +13,7 @@ wd_events = util.vendor_import("watchdog.events")
 logger = logging.getLogger(__name__)
 
 
-class FileEventHandler(object):
+class FileEventHandler:
     def __init__(self, file_path, save_name, api, file_pusher, *args, **kwargs):
         self.file_path = file_path
         # Convert windows paths to unix paths
@@ -83,8 +82,8 @@ class PolicyEnd(FileEventHandler):
 
 
 class PolicyLive(FileEventHandler):
-    """This policy will upload files every RATE_LIMIT_SECONDS as it 
-        changes throttling as the size increases"""
+    """This policy will upload files every RATE_LIMIT_SECONDS as it
+    changes throttling as the size increases"""
 
     TEN_MB = 10000000
     HUNDRED_MB = 100000000
@@ -94,9 +93,7 @@ class PolicyLive(FileEventHandler):
     RATE_LIMIT_SIZE_INCREASE = 1.2
 
     def __init__(self, file_path, save_name, api, file_pusher, *args, **kwargs):
-        super(PolicyLive, self).__init__(
-            file_path, save_name, api, file_pusher, *args, **kwargs
-        )
+        super().__init__(file_path, save_name, api, file_pusher, *args, **kwargs)
         self._last_uploaded_time = None
         self._last_uploaded_size = 0
 
@@ -152,7 +149,7 @@ class PolicyLive(FileEventHandler):
         return "live"
 
 
-class DirWatcher(object):
+class DirWatcher:
     def __init__(self, settings, api, file_pusher, file_dir=None):
         self._api = api
         self._file_count = 0
@@ -191,8 +188,7 @@ class DirWatcher(object):
             feh.on_modified(force=True)
 
     def _per_file_event_handler(self):
-        """Create a Watchdog file event handler that does different things for every file
-        """
+        """Create a Watchdog file event handler that does different things for every file"""
         file_event_handler = wd_events.PatternMatchingEventHandler()
         file_event_handler.on_created = self._on_file_created
         file_event_handler.on_modified = self._on_file_modified
@@ -262,7 +258,7 @@ class DirWatcher(object):
                 )
             else:
                 Handler = PolicyEnd
-                for policy, globs in six.iteritems(self._user_file_policies):
+                for policy, globs in self._user_file_policies.items():
                     if policy == "end":
                         continue
                     # Convert set to list to avoid RuntimeError's
