@@ -1,12 +1,7 @@
-# -*- coding: utf-8 -*-
 """
 keras init
 """
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-from __future__ import unicode_literals
 
 import logging
 import numpy as np
@@ -208,14 +203,14 @@ def is_numeric_array(array):
 
 def _warn_not_logging_non_numeric(name):
     wandb.termwarn(
-        "Non-numeric values found in layer: {}, not logging this layer".format(name),
+        f"Non-numeric values found in layer: {name}, not logging this layer",
         repeat=False,
     )
 
 
 def _warn_not_logging(name):
     wandb.termwarn(
-        "Layer {} has undetermined datatype not logging this layer".format(name),
+        f"Layer {name} has undetermined datatype not logging this layer",
         repeat=False,
     )
 
@@ -230,7 +225,7 @@ patch_tf_keras()
 
 class _CustomOptimizer(tf.keras.optimizers.Optimizer):
     def __init__(self):
-        super(_CustomOptimizer, self).__init__(name="CustomOptimizer")
+        super().__init__(name="CustomOptimizer")
         self._resource_apply_dense = tf.function(self._resource_apply_dense)
         self._resource_apply_sparse = tf.function(self._resource_apply_sparse)
 
@@ -243,7 +238,7 @@ class _CustomOptimizer(tf.keras.optimizers.Optimizer):
         pass
 
     def get_config(self):
-        return super(_CustomOptimizer, self).get_config()
+        return super().get_config()
 
 
 class _GradAccumulatorCallback(tf.keras.callbacks.Callback):
@@ -253,7 +248,7 @@ class _GradAccumulatorCallback(tf.keras.callbacks.Callback):
     """
 
     def set_model(self, model):
-        super(_GradAccumulatorCallback, self).set_model(model)
+        super().set_model(model)
         self.og_weights = model.get_weights()
         self.grads = [np.zeros(tuple(w.shape)) for w in model.trainable_weights]
 
@@ -476,9 +471,7 @@ class WandbCallback(tf.keras.callbacks.Callback):
                 self.monitor_op = operator.lt
                 self.best = float("inf")
         # Get the previous best metric for resumed runs
-        previous_best = wandb.run.summary.get(
-            "%s%s" % (self.log_best_prefix, self.monitor)
-        )
+        previous_best = wandb.run.summary.get(f"{self.log_best_prefix}{self.monitor}")
         if previous_best is not None:
             self.best = previous_best
 
@@ -578,9 +571,9 @@ class WandbCallback(tf.keras.callbacks.Callback):
         if self.current and self.monitor_op(self.current, self.best):
             if self.log_best_prefix:
                 wandb.run.summary[
-                    "%s%s" % (self.log_best_prefix, self.monitor)
+                    f"{self.log_best_prefix}{self.monitor}"
                 ] = self.current
-                wandb.run.summary["%s%s" % (self.log_best_prefix, "epoch")] = epoch
+                wandb.run.summary["{}{}".format(self.log_best_prefix, "epoch")] = epoch
                 if self.verbose and not self.save_model:
                     print(
                         "Epoch %05d: %s improved from %0.5f to %0.5f"
