@@ -1,9 +1,5 @@
-#
-# -*- coding: utf-8 -*-
 """Writer thread."""
 
-from __future__ import print_function
-
 import logging
 
 from . import datastore
@@ -12,9 +8,12 @@ from . import datastore
 logger = logging.getLogger(__name__)
 
 
-class WriteManager(object):
+class WriteManager:
     def __init__(
-        self, settings, record_q, result_q,
+        self,
+        settings,
+        record_q,
+        result_q,
     ):
         self._settings = settings
         self._record_q = record_q
