@@ -94,7 +94,7 @@ def set_project_entity_defaults(
     prefix = ""
     if platform.system() != "Windows" and sys.stdout.encoding == "UTF-8":
         prefix = "🚀 "
-    wandb.termlog("{}Launching run into {}/{}".format(prefix, entity, project))
+    wandb.termlog(f"{prefix}Launching run into {entity}/{project}")
     return project, entity
 
 
@@ -119,7 +119,11 @@ def construct_launch_spec(
     if uri is not None:
         launch_spec["uri"] = uri
     project, entity = set_project_entity_defaults(
-        uri, api, project, entity, launch_config,
+        uri,
+        api,
+        project,
+        entity,
+        launch_config,
     )
     launch_spec["entity"] = entity
 
@@ -278,7 +282,7 @@ def apply_patch(patch_string: str, dst_dir: str) -> None:
             [
                 "patch",
                 "-s",
-                "--directory={}".format(dst_dir),
+                f"--directory={dst_dir}",
                 "-p1",
                 "-i",
                 "diff.patch",
@@ -335,7 +339,7 @@ def convert_jupyter_notebook_to_script(fname: str, project_dir: str) -> str:
 
     _logger.info("Converting notebook to script")
     new_name = fname.rstrip(".ipynb") + ".py"
-    with open(os.path.join(project_dir, fname), "r") as fh:
+    with open(os.path.join(project_dir, fname)) as fh:
         nb = nbformat.reads(fh.read(), nbformat.NO_CONVERT)
 
     exporter = nbconvert.PythonExporter()
