@@ -52,7 +52,6 @@ import requests
 import sentry_sdk  # type: ignore
 from sentry_sdk import capture_exception, capture_message
 import shortuuid  # type: ignore
-import six
 import wandb
 from wandb.env import error_reporting_enabled, get_app_url, SENTRY_DSN
 from wandb.errors import CommError, term, UsageError
@@ -86,7 +85,14 @@ def get_platform_name() -> str:
         return PLATFORM_DARWIN
     elif sys.platform.startswith("linux"):
         return PLATFORM_LINUX
-    elif sys.platform.startswith(("dragonfly", "freebsd", "netbsd", "openbsd",)):
+    elif sys.platform.startswith(
+        (
+            "dragonfly",
+            "freebsd",
+            "netbsd",
+            "openbsd",
+        )
+    ):
         return PLATFORM_BSD
     else:
         return PLATFORM_UNKNOWN
@@ -107,23 +113,23 @@ if error_reporting_enabled():
     )
 
 POW_10_BYTES = [
-    ("B", 10 ** 0),
-    ("KB", 10 ** 3),
-    ("MB", 10 ** 6),
-    ("GB", 10 ** 9),
-    ("TB", 10 ** 12),
-    ("PB", 10 ** 15),
-    ("EB", 10 ** 18),
+    ("B", 10**0),
+    ("KB", 10**3),
+    ("MB", 10**6),
+    ("GB", 10**9),
+    ("TB", 10**12),
+    ("PB", 10**15),
+    ("EB", 10**18),
 ]
 
 POW_2_BYTES = [
-    ("B", 2 ** 0),
-    ("KiB", 2 ** 10),
-    ("MiB", 2 ** 20),
-    ("GiB", 2 ** 30),
-    ("TiB", 2 ** 40),
-    ("PiB", 2 ** 50),
-    ("EiB", 2 ** 60),
+    ("B", 2**0),
+    ("KiB", 2**10),
+    ("MiB", 2**20),
+    ("GiB", 2**30),
+    ("TiB", 2**40),
+    ("PiB", 2**50),
+    ("EiB", 2**60),
 ]
 
 
@@ -164,7 +170,7 @@ def sentry_reraise(exc: Any) -> None:
     sentry_exc(exc)
     # this will messily add this "reraise" function to the stack trace
     # but hopefully it's not too bad
-    six.reraise(type(exc), exc, sys.exc_info()[2])
+    raise exc.with_traceback(sys.exc_info()[2])
 
 
 def sentry_set_scope(
@@ -223,7 +229,7 @@ def sentry_set_scope(
             if all(params.values()):
                 # here we're guaranteed that entity, project, base_url all have valid values
                 app_url = wandb.util.app_url(params["base_url"])
-                e, p = [quote(params[k]) for k in ["entity", "project"]]
+                e, p = (quote(params[k]) for k in ["entity", "project"])
 
                 # TODO: the settings object will be updated to contain run_url and sweep_url
                 # This is done by passing a settings_map in the run_start protocol buffer message
@@ -614,7 +620,7 @@ def json_friendly(  # noqa: C901
         obj = obj.isoformat()
     elif callable(obj):
         obj = (
-            "{}.{}".format(obj.__module__, obj.__qualname__)
+            f"{obj.__module__}.{obj.__qualname__}"
             if hasattr(obj, "__qualname__") and hasattr(obj, "__module__")
             else str(obj)
         )
@@ -885,7 +891,7 @@ def find_runner(program: str) -> Union[None, list, List[str]]:
         # program is a path to a non-executable file
         try:
             opened = open(program)
-        except IOError:  # PermissionError doesn't exist in 2.7
+        except OSError:  # PermissionError doesn't exist in 2.7
             return None
         first_line = opened.readline().strip()
         if first_line.startswith("#!"):
@@ -1030,7 +1036,7 @@ def image_id_from_k8s() -> Optional[str]:
                 k8s_server,
                 verify="/var/run/secrets/kubernetes.io/serviceaccount/ca.crt",
                 timeout=3,
-                headers={"Authorization": "Bearer {}".format(open(token_path).read())},
+                headers={"Authorization": f"Bearer {open(token_path).read()}"},
             )
             res.raise_for_status()
         except requests.RequestException:
@@ -1072,7 +1078,7 @@ def async_call(target: Callable, timeout: Optional[int] = None) -> Callable:
         try:
             result = q.get(True, timeout)
             if isinstance(result, Exception):
-                six.reraise(type(result), result, sys.exc_info()[2])
+                raise result.with_traceback(sys.exc_info()[2])
             return result, thread
         except queue.Empty:
             return None, thread
@@ -1111,7 +1117,10 @@ def class_colors(class_count: int) -> List[List[int]]:
     ]
 
 
-def _prompt_choice(input_timeout: int = None, jupyter: bool = False,) -> str:
+def _prompt_choice(
+    input_timeout: int = None,
+    jupyter: bool = False,
+) -> str:
     input_fn: Callable = input
     prompt = term.LOG_STRING
     if input_timeout is not None:
@@ -1132,7 +1141,9 @@ def _prompt_choice(input_timeout: int = None, jupyter: bool = False,) -> str:
 
 
 def prompt_choices(
-    choices: Sequence[str], input_timeout: int = None, jupyter: bool = False,
+    choices: Sequence[str],
+    input_timeout: int = None,
+    jupyter: bool = False,
 ) -> str:
     """Allow a user to choose from a list of options"""
     for i, choice in enumerate(choices):
@@ -1259,7 +1270,7 @@ def parse_sweep_id(parts_dict: dict) -> Optional[str]:
     entity = None
     project = None
     sweep_id = parts_dict.get("name")
-    if not isinstance(sweep_id, six.string_types):
+    if not isinstance(sweep_id, str):
         return "Expected string sweep_id"
 
     sweep_split = sweep_id.split("/")
@@ -1495,7 +1506,7 @@ def handle_sweep_config_violations(warnings: List[str]) -> None:
 def _log_thread_stacks() -> None:
     """Log all threads, useful for debugging."""
 
-    thread_map = dict((t.ident, t.name) for t in threading.enumerate())
+    thread_map = {t.ident: t.name for t in threading.enumerate()}
 
     for thread_id, frame in sys._current_frames().items():
         logger.info(
@@ -1549,10 +1560,10 @@ def check_dict_contains_nested_artifact(d: dict, nested: bool = False) -> bool:
 def load_json_yaml_dict(config: str) -> Any:
     ext = os.path.splitext(config)[-1]
     if ext == ".json":
-        with open(config, "r") as f:
+        with open(config) as f:
             return json.load(f)
     elif ext == ".yaml":
-        with open(config, "r") as f:
+        with open(config) as f:
             return yaml.safe_load(f)
     else:
         try:
@@ -1625,7 +1636,7 @@ def _is_artifact(v: Any) -> bool:
 
 
 def _is_artifact_string(v: Any) -> bool:
-    return isinstance(v, six.string_types) and v.startswith("wandb-artifact://")
+    return isinstance(v, str) and v.startswith("wandb-artifact://")
 
 
 def parse_artifact_string(v: str) -> Tuple[str, Optional[str]]:
@@ -1661,6 +1672,18 @@ def _get_max_cli_version() -> Union[str, None]:
 
 
 def _is_offline() -> bool:
-    return (  # type: ignore [no-any-return]
+    return (  # type: ignore[no-any-return]
         wandb.run is not None and wandb.run.settings._offline
     ) or wandb.setup().settings._offline
+
+
+def ensure_text(
+    string: Union[str, bytes], encoding: str = "utf-8", errors: str = "strict"
+) -> str:
+    """Coerce s to str."""
+    if isinstance(string, bytes):
+        return string.decode(encoding, errors)
+    elif isinstance(string, str):
+        return string
+    else:
+        raise TypeError(f"not expecting type '{type(string)}'")
