@@ -10,9 +10,7 @@ class Visualize:
 
 def visualize(viz_id, value):
     if not isinstance(value, Table):
-        raise Error(
-            "visualize value must be Table, not {}".format(type(value).__name__)
-        )
+        raise Error(f"visualize value must be Table, not {type(value).__name__}")
     return Visualize(viz_id, value)
 
 
